<?php
namespace PanoramaViewer\Site\BlockLayout;

use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use Laminas\Form\FormElementManager;

use PanoramaViewer\Form\PanoramaViewerBlockForm;

class PanoramaViewer extends AbstractBlockLayout
{
	/**
     * @var FormElementManager
     */
    protected $formElementManager;

    /**
     * @var array
     */
	protected $defaultSettings = [];

    /**
     * @param FormElementManager $formElementManager
     * @param array $defaultSettings
     */
    public function __construct(FormElementManager $formElementManager, array $defaultSettings)
    {
        $this->formElementManager = $formElementManager;
        $this->defaultSettings = $defaultSettings;
    }

	public function getLabel() {
		return 'Panorama Viewer';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(PanoramaViewerBlockForm::class);
		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][panorama_type]' => $data['panorama_type'],
			'o:block[__blockIndex__][o:data][title]' => $data['title'],
			'o:block[__blockIndex__][o:data][width]' => $data['width'],
			'o:block[__blockIndex__][o:data][ratio]' => $data['ratio'],
			'o:block[__blockIndex__][o:data][autoLoad]' => $data['autoLoad'],
			'o:block[__blockIndex__][o:data][renderSourceLink]' => $data['renderSourceLink'],
		]);
		$form->prepare();

		$html = '';
		$html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>' . $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
        $html .= '</div>';
		return $html;
    }

	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
	{
		$attachments = $block->attachments();
        if (!$attachments) {
            return '';
		}

		$urls = [];
    $media_types = [];
    $thumbnails = [];
    $panorama_type = $block->dataValue('panorama_type');
		static $id = 0;

		foreach ($attachments as $attachment)
		{
			foreach($attachment->item()->media() as $media)
			{
				$mediaType = $media->mediaType();
				$mediaRenderer = $media->renderer();
        if ($panorama_type == "video" && strpos($mediaType, 'video/') !== false){
          array_push($urls, $media->originalUrl());
					array_push($media_types, $mediaType);
        } elseif (strpos($mediaType, 'image/') !== false){
          array_push($urls, $media->originalUrl());
        }
        array_push($thumbnails, $media->thumbnailUrls());
			}
		}
    $item_id = $attachments[0]->item()->url();
    //$title = $attachments[0]->item()->title();
		return $view->partial('common/block-layout/panorama-viewer', [
			'panorama_type' => $panorama_type,
			'title' => $block->dataValue('title'),
			'ratio' => $block->dataValue('ratio'),
      'autoLoad' => $block->dataValue('autoLoad'),
      'renderSourceLink' => $block->dataValue('renderSourceLink'),
			'urls' => $urls,
      'id' => 'pv-' . ++$id,
      'mediaTypes' => $media_types,
      'thumbnails' => $thumbnails,
      'item_url' => $attachments[0]->item()->url(),
		]);
	}
}
